==> haskell-config-ini-0.2.6.0-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-ini
version:              0.2.6.0
visibility:           public
id:                   config-ini-0.2.6.0-DepuxquhTun2ZBBgDL2A2C
key:                  config-ini-0.2.6.0-DepuxquhTun2ZBBgDL2A2C
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <config-ini@infinitenegativeutility.com>
author:               Getty Ritter <config-ini@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/config-ini
synopsis:             A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.

    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)

category:             Configuration
abi:                  99e395280c96740ba4edbaa7c3216d76
exposed:              True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw

import-dirs:          /usr/lib/ghc-9.4.8/site-local/config-ini-0.2.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/config-ini-0.2.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/config-ini-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-ini
hs-libraries:         HSconfig-ini-0.2.6.0-DepuxquhTun2ZBBgDL2A2C
depends:
    base-4.17.2.1 containers-0.6.7
    megaparsec-9.6.1-2HDqovyWdJD7TkiDY5U33O text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:   /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html:         /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-ini-0.2.6.0-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-ini
version:              0.2.6.0
visibility:           public
id:                   config-ini-0.2.6.0-H88Ha6zzQIR5CotkagzQeK
key:                  config-ini-0.2.6.0-H88Ha6zzQIR5CotkagzQeK
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <config-ini@infinitenegativeutility.com>
author:               Getty Ritter <config-ini@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/config-ini
synopsis:             A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.

    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)

category:             Configuration
abi:                  a79f8c33e5990b0304b555742499eb57
exposed:              True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw

import-dirs:          /usr/lib/ghc-9.4.8/site-local/config-ini-0.2.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/config-ini-0.2.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/config-ini-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-ini
hs-libraries:         HSconfig-ini-0.2.6.0-H88Ha6zzQIR5CotkagzQeK
depends:
    base-4.17.2.1 containers-0.6.7
    megaparsec-9.6.1-9jbfOTjnDTaHWZ1zNhDVr9 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-I6MqYi1ZitpKUe3ww5yyKM

haddock-interfaces:   /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html:         /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
